@@ -12,14 +12,16 @@
 #include <memory>
 
 #include "odil/Association.h"
+#include "odil/odil.h"
 #include "odil/SCP.h"
+#include "odil/message/CFindRequest.h"
 #include "odil/message/Message.h"
 
 namespace odil
 {
 
 /// @brief SCP for C-Find services.
-class FindSCP: public SCP
+class ODIL_API FindSCP: public SCP
 {
 public:
 
@@ -43,8 +45,13 @@ public:
     /// @brief Process a C-Find request.
     virtual void operator()(message::Message const & message);
 
+    /// @brief Process a C-Find request.
+    virtual void operator()(message::Message && message);
+
 private:
     std::shared_ptr<DataSetGenerator> _generator;
+
+    void operator()(message::CFindRequest const & request);
 };
 
 }
