@@ -12,14 +12,16 @@
 #include <memory>
 
 #include "odil/Association.h"
+#include "odil/odil.h"
 #include "odil/SCP.h"
+#include "odil/message/CGetRequest.h"
 #include "odil/message/Message.h"
 
 namespace odil
 {
 
 /// @brief SCP for C-Get services.
-class GetSCP: public SCP
+class ODIL_API GetSCP: public SCP
 {
 public:
 
@@ -51,8 +53,12 @@ public:
     /// @brief Process a C-Get request.
     virtual void operator()(message::Message const & message);
 
+    /// @brief Process a C-Get request.
+    virtual void operator()(message::Message && message);
+
 private:
     std::shared_ptr<DataSetGenerator> _generator;
+    void operator()(message::CGetRequest const & request);
 };
 
 }
