@@ -12,6 +12,7 @@
 #include <cstdint>
 #include <functional>
 #include <istream>
+#include <memory>
 #include <sstream>
 #include <string>
 #include <utility>
@@ -141,7 +142,7 @@ Reader
 
             if(this->keep_group_length || tag.element != 0)
             {
-                data_set.add(tag, element);
+                data_set.add(tag, std::move(element));
             }
         }
 
@@ -210,56 +211,43 @@ Reader
         vr = vr_finder(tag, data_set, this->transfer_syntax);
     }
 
-    Value value;
+    std::shared_ptr<Value> value;
 
     auto const vl = this->read_length(vr);
-    if(vl == 0)
+    if(is_int(vr))
     {
-        value = Value();
+        value = std::make_shared<Value>(Value::Integers());
     }
-    else if(vr == VR::IS || vr == VR::SL || vr == VR::SS ||
-        vr == VR::UL || vr == VR::US)
+    else if(is_real(vr))
     {
-        value = Value(Value::Integers());
+        value = std::make_shared<Value>(Value::Reals());
     }
-    else if(vr == VR::DS || vr == VR::FD || vr == VR::FL)
+    else if(is_string(vr))
     {
-        value = Value(Value::Reals());
-    }
-    else if(vr == VR::AE || vr == VR::AS || vr == VR::AT || vr == VR::CS ||
-        vr == VR::DA || vr == VR::DS || vr == VR::DT || vr == VR::LO ||
-        vr == VR::LT || vr == VR::PN || vr == VR::SH || vr == VR::ST ||
-        vr == VR::TM || vr == VR::UC || vr == VR::UI || vr == VR::UR ||
-        vr == VR::UT)
-    {
-        value = Value(Value::Strings());
+        value = std::make_shared<Value>(Value::Strings());
     }
     else if(vr == VR::SQ)
     {
-        value = Value(Value::DataSets());
+        value = std::make_shared<Value>(Value::DataSets());
     }
     else if(is_binary(vr))
     {
-        value = Value(Value::Binary());
+        value = std::make_shared<Value>(Value::Binary());
     }
     else
     {
         throw Exception("Cannot create value for VR " + as_string(vr));
     }
 
-    if(!value.empty())
+    if(vl > 0)
     {
         Visitor visitor(
             this->stream, vr, vl, this->transfer_syntax, this->byte_ordering,
             this->explicit_vr, this->keep_group_length);
-        apply_visitor(visitor, value);
-        if(vr == VR::SQ && value.as_data_sets().empty())
-        {
-            value = Value();
-        }
+        apply_visitor(visitor, *value);
     }
 
-    return Element(value, vr);
+    return Element(*value, vr);
 }
 
 std::pair<DataSet, DataSet>
@@ -285,7 +273,7 @@ Reader
     // Read meta information
     Reader meta_information_reader(
         stream, registry::ExplicitVRLittleEndian, keep_group_length);
-    auto const meta_information = meta_information_reader.read_data_set(
+    auto meta_information = meta_information_reader.read_data_set(
         [](Tag const & tag) { return (tag.group != 0x0002); });
 
     if(!meta_information.has(registry::TransferSyntaxUID))
@@ -304,9 +292,9 @@ Reader
     Reader data_set_reader(
         stream, meta_information.as_string(registry::TransferSyntaxUID)[0],
         keep_group_length);
-    auto const data_set = data_set_reader.read_data_set(halt_condition);
+    auto data_set = data_set_reader.read_data_set(halt_condition);
 
-    return std::pair<DataSet, DataSet>(meta_information, data_set);
+    return std::make_pair(std::move(meta_information), std::move(data_set));
 }
 
 Reader::Visitor
