@@ -60,14 +60,28 @@ void
 StoreSCP
 ::operator()(message::Message const & message)
 {
-    message::CStoreRequest const request(message);
+    message::CStoreRequest request(message);
+    this->operator()(request);
+}
 
+void
+StoreSCP
+::operator()(message::Message && message)
+{
+    message::CStoreRequest request(std::move(message));
+    this->operator()(request);
+}
+
+void
+StoreSCP
+::operator()(message::CStoreRequest & request)
+{
     Value::Integer status=message::CStoreResponse::Success;
     DataSet status_fields;
 
     try
     {
-        status = this->_callback(request);
+        status = this->_callback(std::move(request));
     }
     catch(SCP::Exception const & e)
     {
