@@ -17,6 +17,7 @@
 #include "odil/message/CStoreResponse.h"
 #include "odil/DataSet.h"
 #include "odil/Exception.h"
+#include "odil/logging.h"
 #include "odil/registry.h"
 #include "odil/SCU.h"
 
@@ -66,8 +67,8 @@ void
 StoreSCU
 ::store(
     DataSet const & dataset,
-    Value::String const & move_originator_ae_title,
-    Value::Integer move_originator_message_id) const
+    Value::String const & move_originator_ae_title ,
+    Value::Integer move_originator_message_id ) const
 {
     message::CStoreRequest const request(
         this->_association.next_message_id(),
@@ -76,7 +77,30 @@ StoreSCU
         message::Message::Priority::MEDIUM,
         dataset, move_originator_ae_title,
         move_originator_message_id);
+    this->_store(request);
+}
 
+void
+StoreSCU
+::store(
+    DataSet && dataset,
+    Value::String const & move_originator_ae_title ,
+    Value::Integer move_originator_message_id ) const
+{
+    message::CStoreRequest const request(
+        this->_association.next_message_id(),
+        this->_affected_sop_class,
+        dataset.as_string(registry::SOPInstanceUID, 0),
+        message::Message::Priority::MEDIUM,
+        std::move(dataset), move_originator_ae_title,
+        move_originator_message_id);
+    this->_store(request);
+}
+
+void
+StoreSCU
+::_store(message::CStoreRequest const & request) const
+{
     this->_association.send_message(request, this->_affected_sop_class);
     
     message::CStoreResponse const response = this->_association.receive_message();
@@ -108,6 +132,15 @@ StoreSCU
                 << " (expected: " << request.get_affected_sop_instance_uid() << ")";
         throw Exception(message.str());
     }
+
+    if(message::Response::is_warning(response.get_status()))
+    {
+        ODIL_LOG(WARN) << "C-STORE response status: " << response.get_status();
+    }
+    else if(message::Response::is_failure(response.get_status()))
+    {
+        ODIL_LOG(ERROR) << "C-STORE response status: " << response.get_status();
+    }
 }
 
 }
