@@ -11,9 +11,12 @@
 
 #include <cstdint>
 #include <initializer_list>
+#include <memory>
 #include <string>
 #include <vector>
 
+#include "odil/odil.h"
+
 namespace odil
 {
 
@@ -22,13 +25,12 @@ class DataSet;
 /**
  * @brief A value held in a DICOM element.
  */
-class Value
+class ODIL_API Value
 {
 public:
     /// @brief Possible types stored in the value.
     enum class Type
     {
-        Empty,
         Integers,
         Reals,
         Strings,
@@ -60,38 +62,35 @@ public:
     /// @brief Binary data container.
     typedef std::vector<std::vector<uint8_t>> Binary;
 
-    /// @brief Build an empty value.
-    Value();
+#define ODIL_VALUE_CONSTRUCTORS(type) \
+    Value(type const & value); \
+    Value(type && value); \
+    Value(std::initializer_list<type::value_type> const & value);
+    /*
+     * No need for for a rvalue reference version of std::initializer_list:
+     * copying a std::initializer_list does not copy the underlying objects.
+     */
 
-    /// @brief Build a value from integers.
-    Value(Integers const & integers);
+    ODIL_VALUE_CONSTRUCTORS(Integers);
+    ODIL_VALUE_CONSTRUCTORS(Reals);
+    ODIL_VALUE_CONSTRUCTORS(Strings);
+    ODIL_VALUE_CONSTRUCTORS(DataSets);
+    ODIL_VALUE_CONSTRUCTORS(Binary);
+#undef ODIL_VALUE_CONSTRUCTORS
 
-    /// @brief Build a value from reals.
-    Value(Reals const & reals);
+    Value(std::initializer_list<int> const & value);
 
-    /// @brief Build a value from strings.
-    Value(Strings const & strings);
+    Value(std::initializer_list<std::initializer_list<uint8_t>> const & value);
 
-    /// @brief Build a value from data sets.
-    Value(DataSets const & datasets);
-
-    /// @brief Build a value from binary data.
-    Value(Binary const & binary);
-
-    /// @brief Build a value from integers.
-    Value(std::initializer_list<int> const & list);
-
-    /// @brief Build a value from integers.
-    Value(std::initializer_list<Integer> const & list);
-
-    /// @brief Build a value from reals.
-    Value(std::initializer_list<Real> const & list);
-
-    /// @brief Build a value from strings.
-    Value(std::initializer_list<String> const & list);
-
-    /// @brief Build a value from data sets.
-    Value(std::initializer_list<DataSet> const & list);
+    /** @addtogroup default_operations Default class operations
+     * @{
+     */
+    ~Value() =default;
+    Value(Value const &) =default;
+    Value(Value &&) =default;
+    Value & operator=(Value const &) =default;
+    Value & operator=(Value &&) =default;
+    /// @}
 
     /// @brief Return the type store in the value.
     Type get_type() const;
@@ -99,6 +98,9 @@ public:
     /// @brief Test whether the value is empty.
     bool empty() const;
 
+    /// @brief Return the number of items.
+    std::size_t size() const;
+
     /**
      * @brief Return the integers contained in the value.
      *
@@ -175,11 +177,16 @@ public:
     /// @brief Difference test.
     bool operator!=(Value const & other) const;
 
+    /// @brief Clear the value (value.empty() will be true).
+    void clear();
+
 private:
     Integers _integers;
     Reals _reals;
     Strings _strings;
-    DataSets _data_sets;
+    // NOTE: can't use std::vector<DataSet> with forward-declaration of DataSet
+    // cf. C++11, 17.6.4.8, last bullet of clause 2
+    std::shared_ptr<DataSets> _data_sets;
     Binary _binary;
 
     Type _type;
