@@ -11,6 +11,8 @@
 
 #include <string>
 
+#include "odil/odil.h"
+
 namespace odil
 {
 
@@ -18,10 +20,10 @@ namespace base64
 {
 
 /// @brief Dictionary of symbols for Base64.
-extern std::string const symbols;
+extern ODIL_API std::string const symbols;
 
 /// @brief Mapping of ASCII characters to values of Base64 symbols.
-extern std::string const reversed_symbols;
+extern ODIL_API std::string const reversed_symbols;
 
 /// @brief Encode a sequence of 8 bits data to Base64.
 template<typename TInputIterator, typename TOutputIterator>
