@@ -12,18 +12,19 @@
 #include <json/json.h>
 
 #include "odil/DataSet.h"
+#include "odil/odil.h"
 #include "odil/Value.h"
 
 namespace odil
 {
 
 /// @brief Convert a data set to its JSON representation.
-Json::Value as_json(
+ODIL_API Json::Value as_json(
     DataSet const & data_set,
     odil::Value::Strings const & specific_character_set=odil::Value::Strings());
 
 /// @brief Create a data set from its JSON representation.
-DataSet as_dataset(Json::Value const & json);
+ODIL_API DataSet as_dataset(Json::Value const & json);
 
 }
 
