@@ -9,6 +9,7 @@
 #ifndef _74cfa9e7_da35_4130_a941_e17cb6932f60
 #define _74cfa9e7_da35_4130_a941_e17cb6932f60
 
+#include "odil/odil.h"
 #include "odil/registry.h"
 #include "odil/message/Request.h"
 #include "odil/Value.h"
@@ -20,7 +21,7 @@ namespace message
 {
 
 /// @brief C-FIND-RQ message.
-class CFindRequest: public Request
+class ODIL_API CFindRequest: public Request
 {
 public:
     /**
@@ -31,6 +32,14 @@ public:
         Value::Integer message_id, Value::String const & affected_sop_class_uid,
         Value::Integer priority, DataSet const & dataset);
 
+    /**
+     * @brief Create an find request with given Message ID,
+     * affected SOP class UID, priority, and data set.
+     */
+    CFindRequest(
+        Value::Integer message_id, Value::String const & affected_sop_class_uid,
+        Value::Integer priority, DataSet && dataset);
+
     /**
      * @brief Create a C-FIND-RQ from a generic Message.
      *
@@ -38,12 +47,25 @@ public:
      */
     CFindRequest(Message const & message);
 
+    /**
+     * @brief Create a C-FIND-RQ from a generic Message.
+     *
+     * Raise an exception if the Message does not contain a C-FIND-RQ.
+     */
+    CFindRequest(Message && message);
+
     /// @brief Destructor.
     virtual ~CFindRequest();
     
     ODIL_MESSAGE_MANDATORY_FIELD_STRING_MACRO(
         affected_sop_class_uid, registry::AffectedSOPClassUID)
     ODIL_MESSAGE_MANDATORY_FIELD_INTEGER_MACRO(priority, registry::Priority)
+
+private:
+    void _create(
+        Value::String const & affected_sop_class_uid, Value::Integer priority,
+        DataSet const & dataset);
+    void _parse(Message const & message);
 };
 
 }
