@@ -10,6 +10,7 @@
 #define _0dd2e31e_212a_494a_a8d3_93b235336658
 
 #include "odil/message/Message.h"
+#include "odil/odil.h"
 #include "odil/registry.h"
 #include "odil/Value.h"
 
@@ -20,7 +21,7 @@ namespace message
 {
 
 /// @brief Base class for all DIMSE response messages.
-class Response: public Message
+class ODIL_API Response: public Message
 {
 public:
     /// @brief General status codes, from PS3.7, C
