@@ -49,7 +49,7 @@ public:
             {"1.2.826.0.1.3680043.9.5560.3127449359877365688774406533090568532"});
         data_set_1.add("PatientName", {"Hello^World"});
         data_set_1.add("PatientID", {"1234"});
-        this->_responses.push_back(data_set_1);
+        this->_responses.push_back(std::move(data_set_1));
 
         odil::DataSet data_set_2;
         data_set_2.add("SOPClassUID", {odil::registry::RawDataStorage});
@@ -58,7 +58,7 @@ public:
             {"1.2.826.0.1.3680043.9.5560.3221615743193123463515381981101110692"});
         data_set_2.add("PatientName", {"Doe^John"});
         data_set_2.add("PatientID", {"5678"});
-        this->_responses.push_back(data_set_2);
+        this->_responses.push_back(std::move(data_set_2));
 
         this->_response_iterator = this->_responses.begin();
     }
@@ -70,7 +70,7 @@ public:
 
     virtual odil::DataSet get() const
     {
-        return *this->_response_iterator;
+        return *std::make_move_iterator(this->_response_iterator);
     }
 
     virtual void next()
@@ -84,8 +84,8 @@ public:
     }
 
 private:
-    std::vector<odil::DataSet> _responses;
-    std::vector<odil::DataSet>::const_iterator _response_iterator;
+    mutable std::vector<odil::DataSet> _responses;
+    std::vector<odil::DataSet>::iterator _response_iterator;
 };
 
 void run_server(Status * status)
@@ -101,9 +101,9 @@ void run_server(Status * status)
         auto const generator = std::make_shared<Generator>();
         get_scp.set_generator(generator);
 
-        // Get echo message
-        auto const message = association.receive_message();
-        get_scp(message);
+        // Get C-GET message
+        auto message = association.receive_message();
+        get_scp(std::move(message));
         // Should throw with peer closing connection
         association.receive_message();
     }
@@ -149,8 +149,8 @@ void run_client(Status * status)
         }
 
         std::ifstream stream(it->path().string());
-        auto const data_set = odil::Reader::read_file(stream).second;
-        status->responses.push_back(data_set);
+        auto data_set = odil::Reader::read_file(stream).second;
+        status->responses.push_back(std::move(data_set));
 
         boost::filesystem::remove(it->path());
     }
