@@ -84,6 +84,22 @@ BOOST_FIXTURE_TEST_CASE(Move, Fixture)
             odil::Value::Strings{"2.25.95090344942250266709587559073467305647"});
 }
 
+BOOST_FIXTURE_TEST_CASE(MoveMove, Fixture)
+{
+    odil::MoveSCU scu(this->association);
+    scu.set_move_destination("LOCAL");
+    scu.set_incoming_port(11113);
+
+    scu.set_affected_sop_class(
+        odil::registry::PatientRootQueryRetrieveInformationModelMOVE);
+    auto const results = scu.move(std::move(this->query));
+
+    BOOST_REQUIRE_EQUAL(results.size(), 1);
+    BOOST_CHECK(
+        results[0].as_string("SOPInstanceUID") ==
+            odil::Value::Strings{"2.25.95090344942250266709587559073467305647"});
+}
+
 BOOST_FIXTURE_TEST_CASE(MoveBothCallback, Fixture)
 {
     odil::MoveSCU scu(this->association);
@@ -98,6 +114,22 @@ BOOST_FIXTURE_TEST_CASE(MoveBothCallback, Fixture)
     BOOST_CHECK(Fixture::move_callback_called);
 }
 
+BOOST_FIXTURE_TEST_CASE(MoveBothCallbackMove, Fixture)
+{
+    odil::MoveSCU scu(this->association);
+    scu.set_move_destination("LOCAL");
+    scu.set_incoming_port(11113);
+
+    scu.set_affected_sop_class(
+        odil::registry::PatientRootQueryRetrieveInformationModelMOVE);
+    scu.move(
+        std::move(this->query), Fixture::store_callback,
+        Fixture::move_callback);
+
+    BOOST_CHECK(Fixture::store_callback_called);
+    BOOST_CHECK(Fixture::move_callback_called);
+}
+
 BOOST_FIXTURE_TEST_CASE(MoveOnlyStoreCallback, Fixture)
 {
     odil::MoveSCU scu(this->association);
@@ -112,3 +144,19 @@ BOOST_FIXTURE_TEST_CASE(MoveOnlyStoreCallback, Fixture)
     BOOST_CHECK(Fixture::store_callback_called);
     BOOST_CHECK(!Fixture::move_callback_called);
 }
+
+BOOST_FIXTURE_TEST_CASE(MoveOnlyStoreCallbackMove, Fixture)
+{
+    odil::MoveSCU scu(this->association);
+    scu.set_move_destination("LOCAL");
+    scu.set_incoming_port(11113);
+
+    scu.set_affected_sop_class(
+        odil::registry::PatientRootQueryRetrieveInformationModelMOVE);
+    scu.move(
+        std::move(this->query), Fixture::store_callback,
+        odil::MoveSCU::MoveCallback());
+
+    BOOST_CHECK(Fixture::store_callback_called);
+    BOOST_CHECK(!Fixture::move_callback_called);
+}
