@@ -6,22 +6,24 @@
  * for details.
  ************************************************************************/
 
+#include "odil/StoreSCP.h"
+
 #include <boost/python.hpp>
 
-#include "odil/StoreSCP.h"
+#include <functional>
 
 namespace
 {
-
-void 
-set_callback(odil::StoreSCP & scp, boost::python::object const & f)
+using namespace std;
+void
+set_callback(odil::StoreSCP& scp, boost::python::object const& f)
 {
     scp.set_callback(
-        [f](odil::message::CStoreRequest const & message) 
-        { 
+        [f](odil::message::CStoreRequest const& message)
+        {
             return boost::python::call<odil::Value::Integer>(f.ptr(), message);
         }
-    );
+        );
 }
 
 }
@@ -29,10 +31,19 @@ set_callback(odil::StoreSCP & scp, boost::python::object const & f)
 void wrap_StoreSCP()
 {
     using namespace boost::python;
+    using namespace std;
     using namespace odil;
 
-    class_<StoreSCP>("StoreSCP", init<Association &>())
-        .def("set_callback", &set_callback)
-        .def("__call__", &StoreSCP::operator())
+//    class_<StoreSCP, bases<SCP>>("StoreSCP", init<Association &>())
+    class_<StoreSCP>("StoreSCP", init<Association&>())
+    .def(init<Association&, StoreSCP::Callback& >())
+    .def("set_callback", &set_callback)
+    .def(
+        "__call__",
+        static_cast<
+            void (StoreSCP::*)(message::Message const &)
+        >(&StoreSCP::operator())
+    )
     ;
+
 }
